import base64
import configparser
import os
import re
from getpass import getpass

from invoke import task
from py_odoo.py_odoo import Odoo

valid_email = re.compile(r"""^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,63}$""", re.VERBOSE)
cfile = '~/.pyodoodesk.ini'

OdooDesk = Odoo(cfile)


@task
def setup(ctx):
    """
    Save Odoo Username / Password
    """

    email_addr = ''
    password = ''
    database = ''
    server_url = ''

    while not database:
        db = input('Odoo Database: ')
        if db:
            database = db.strip()

    while not server_url:
        url = input('Odoo Server URL: ')
        if not url.startswith('http'):
            print('URL must start with http or https')
        else:
            server_url = url.strip()

    while not email_addr:
        email = input('Odoo Email address: ')
        if valid_email.search(email):
            email_addr = email.strip()

    while not password:
        password = getpass('Odoo Password: ')
        try:
            password = bytes(password, encoding='utf8')
        except TypeError:
            pass
        password = base64.urlsafe_b64encode(password.strip()).decode()

    cfg = configparser.ConfigParser()
    cfg.read(cfile)
    cfg['Connection'] = {
        'email': email_addr,
        'password': password,
        'server_url': server_url,
        'database': database,
    }

    with open(os.path.expanduser(cfile), 'w') as configfile:
        cfg.write(configfile)


__all__ = (
    'setup',
    'OdooDesk',
)
