from invoke import task

from .account import OdooDesk


def get_employee_data(odoo) -> dict:
    odoo.load('hr.employee')

    try:
        employee = odoo.search(
            ([('work_email', '=', odoo.uname)]),
            fields=(
                'id',
                'attendance_state',
            ),
        ).json()
    except Exception as e:
        raise SystemExit(f'An error occurred while retrieving employee data: {e}')

    if not employee['count']:
        raise SystemExit('No employee found for your user')

    try:
        return employee['data'][0]
    except (KeyError, IndexError) as e:
        raise SystemExit(f'An error occurred while retrieving employee data: {e}')


@task
def checkin(ctx):
    """
    Attendance Check In
    """
    employee_data = get_employee_data(OdooDesk)

    if employee_data['attendance_state'] == 'checked_in':
        raise SystemExit('You are already checked in!')

    try:
        data = OdooDesk.rpc(employee_data['id'], 'attendance_action_change').json()
    except Exception as e:
        raise SystemExit(f"An error occurred while performing checkin: {e}")

    if data.get('type') == 'exception':
        print(f"An error occurred during checkin: {data.get('message')}")


@task
def checkout(ctx):
    """
    Attendance Check Out
    """
    employee_data = get_employee_data(OdooDesk)

    if employee_data['attendance_state'] == 'checked_out':
        raise SystemExit('Cannot check out - you are not checked in!')

    try:
        data = OdooDesk.rpc(employee_data['id'], 'attendance_action_change').json()
    except Exception as e:
        raise SystemExit(f"An error occurred while performing checkout: {e}")

    if data.get('type') == 'exception':
        print(f"An error occurred during checkout: {data.get('message')}")


__all__ = (
    'checkin',
    'checkout',
)
