from invoke import task

from .account import OdooDesk


def get_task_id(odoo, name) -> int:
    """
    Return task ID
    """
    odoo.load('project.task')
    try:
        tasks = odoo.search(([
            '|',
            ('name', '=', name),
            ('code', 'ilike', name),
        ]), fields=('id',)).json()
    except Exception as e:
        raise SystemExit(f'An error occurred while getting task id: {e}')

    if not tasks['count']:
        raise SystemExit(f'No task with name/code "{name}" could be found')
    elif tasks['count'] > 1:
        raise SystemExit(f'Multiple tasks matched {name}')

    return tasks['data'][0]['id']


@task
def start(ctx, name):
    """
    Start Timesheet Timer
    """
    task_id = get_task_id(OdooDesk, name)

    try:
        data = OdooDesk.rpc(task_id, 'timer_start').json()
    except Exception as e:
        raise SystemExit(f'An error occurred while starting task timer: {e}')

    if data.get('type') == 'exception':
        print(f"An error occurred when starting task timer: {data.get('message')}")


@task
def pause(ctx, name):
    """
    Pause Timesheet Timer
    """
    task_id = get_task_id(OdooDesk, name)

    try:
        data = OdooDesk.rpc(task_id, 'timer_pause').json()
    except Exception as e:
        raise SystemExit(f'An error occurred while pausing task timer: {e}')

    if data.get('type') == 'exception':
        print(f"An error occurred when pausing task timer: {data.get('message')}")


@task
def stop(ctx, name):
    """
    Stop Timesheet Timer
    """
    task_id = get_task_id(OdooDesk, name)

    summary = ''
    while not summary:
        txt = input('Work Description: ')
        if txt:
            summary = txt

    try:
        data = OdooDesk.rpc(task_id, 'api_timer_stop', {'summary': summary}).json()
    except Exception as e:
        raise SystemExit(f'An error occurred while stopping task timer: {e}')

    if data.get('type') == 'exception':
        print(f"An error occurred when stopping task timer: {data.get('message')}")


@task
def tlist(ctx):
    """
    Get list of all active / WIP timesheets
    """
    OdooDesk.load('project.task')

    try:
        tasks = OdooDesk.search(([
            ('timesheet_ids.user_id.email', '=', OdooDesk.uname),
            ('timesheet_ids.timer_status', 'in', ('running', 'paused')),
        ]),
            fields=('code', 'name'),
        ).json()
    except Exception as e:
        raise SystemExit(f'An error occurred while retrieving task list: {e}')

    if not tasks['count']:
        raise SystemExit('You have no active / WIP timesheets')

    for tsk in tasks['data']:
        print(f"{tsk['code']} - {tsk['name']}")


__all__ = (
    'start',
    'pause',
    'stop',
    'tlist',
)
