#!/usr/bin/env python3
import io
import os
import re
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))
with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = '\n' + f.read()


def get_version():
    with open('pyodoodesk/__init__.py', 'r') as f:
        line = f.readline()
        match = re.match(r'__version__ = \'([\d\.]+)\'', line)

        if not match:
            raise ImportError("Can't read the version of pyodoodesk")

        version = match.group(1)
        return version


setup(name='pyodoodesk',
      version=get_version(),
      description="Python CLI for Odoo",
      long_description=long_description,
      author='Dave Burkholder',
      author_email='dave@thinkwelldesigns.com',
      packages=find_packages(exclude=["tests"]),
      package_dir={'': '.'},
      license='MIT',
      zip_safe=True,
      url='https://code.compassfoundation.io/odoo/pyodoodesk',
      include_package_data=True,
      install_requires=[
          'invoke',
          'py_odoo',
      ],
      classifiers=[
          'Environment :: Web Environment',
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python',
          'Topic :: Internet :: WWW/HTTP',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: Implementation :: CPython',
      ],
      entry_points={
          'console_scripts': ['odoo = pyodoodesk.main:program.run'],
      })
